@@ -272,14 +272,11 @@ class Customer(object):
                 "{} Customer from Aiguillier".format(msg),
                 str(e)
             )
-        LOGS.logger.info("{} un client {}-{}-{}-{}".format(
-            msg,
-            self.name,
-            policy_name,
-            period,
-            response['status']
-            ))
-        if (response['status']).lower() == '200':
+            return {
+                'code': '400',
+                'message': 'ERROR {} COTE AIGUILLIER'.format(msg)
+            }
+        if response.get('status') == 200:
             url = core.database_url(**FUPDB_CREDENTIALS)
             with records.Database(url) as db:
                 sql = (
